"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.resolveAppProps = resolveAppProps;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _browser = require("mwp-store/lib/browser");

var _util = require("mwp-router/lib/util");

var _BrowserApp = _interopRequireDefault(require("mwp-app-render/lib/components/BrowserApp"));

/*
 * Ensures that all async parts of the app that are needed for initial render
 * are downloaded before returning
 */
function resolveAppProps(routes, reducer) {
  var middleware = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
  var basename = window.APP_RUNTIME.appContext.basename || '';
  var findMatches = (0, _util.getFindMatches)(routes, basename);
  var createStore = (0, _browser.getBrowserCreateStore)(findMatches, middleware);
  var store = createStore(reducer, (0, _browser.getInitialState)(window.APP_RUNTIME)); // find the matched routes, and then resolve their components - mutate
  // the route object so that the overall `routes` object contains
  // resolved `component` properties for the current location

  var resolveComponents = function resolveComponents() {
    // get an array of matched routes
    var matchedRoutes = findMatches(window.location); // resolve components in parallel (AJAX chunk requests)

    return Promise.all(matchedRoutes.map(function (matchedRoute) {
      if (matchedRoute.route.getComponent) {
        return matchedRoute.route.getComponent();
      }

      return Promise.resolve(matchedRoute.route.component);
    })).then(function (components) {
      // mutate route objects in place
      matchedRoutes.forEach(function (matchedRoute, i) {
        matchedRoute.route.component = components[i];
      });
    });
  }; // when component chunks are resolved, return the props expected by
  // <BrowserApp>


  return resolveComponents().then(function () {
    return {
      routes: routes,
      store: store,
      appContext: window.APP_RUNTIME.appContext
    };
  });
}
/**
 * This function creates a 'renderer', which is just a function that, when
 * called, will call ReactDOM.render() to render the application
 *
 * The routes, reducer, and app-specific middleware are provided by the
 * application - everything else is general to the meetup web platform
 *
 * @deprecated see CHANGELOG v2.4
 */


function makeRenderer(routes, reducer) {
  var middleware = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];
  return function () {
    var rootElId = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'outlet';
    var rootEl = document.getElementById(rootElId);

    if (!rootEl) {
      throw new Error("React root element ".concat(rootElId, " does not exist"));
    }

    resolveAppProps(routes, reducer, middleware).then(function (props) {
      _reactDom.default.render(_react.default.createElement(_BrowserApp.default, props), rootEl);

      return props.store;
    });
  };
}

var _default = makeRenderer;
exports.default = _default;
//# sourceMappingURL=browser-render.js.map