"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _react = _interopRequireDefault(require("react"));

var _reactHelmet = _interopRequireDefault(require("react-helmet"));

var _reactApollo = require("react-apollo");

var _mobileDetect = _interopRequireDefault(require("mobile-detect"));

var _isbot = _interopRequireDefault(require("isbot"));

var _mwpApiProxyPlugin = require("mwp-api-proxy-plugin");

var _mwpRouter = require("mwp-router");

var _util = require("mwp-router/lib/util");

var _server = require("mwp-store/lib/server");

var _Dom = _interopRequireDefault(require("mwp-app-render/lib/components/Dom"));

var _getClient = _interopRequireDefault(require("mwp-app-render/lib/util/getClient"));

var _ServerApp = _interopRequireDefault(require("mwp-app-render/lib/components/ServerApp"));

var _cookieUtils = require("mwp-core/lib/util/cookieUtils");

var _requestUtils = require("mwp-core/lib/util/requestUtils");

var _cookieUtils2 = require("../util/cookieUtils");

var _launchDarkly = require("../util/launchDarkly");

var _getRedirect = _interopRequireDefault(require("../util/getRedirect"));

var _domainCleanup = require("../util/domainCleanup");

var DOCTYPE = '<!DOCTYPE html>';
/**
 * An async module that renders the full app markup for a particular URL/location
 * using [ReactDOMServer]{@link https://facebook.github.io/react/docs/top-level-api.html#reactdomserver}
 *
 * @module ServerRender
 */

function getHtml(el) {
  // const htmlMarkup = ReactDOMServer.renderToString(el);
  // return `${DOCTYPE}${htmlMarkup}`;
  return (0, _reactApollo.renderToStringWithData)(el).then(function (htmlMarkup) {
    return "".concat(DOCTYPE).concat(htmlMarkup);
  });
}
/*
 * A helper to collect react-side-effect data from all components in the
 * application that utilize side effects
 *
 * Any component class that uses react-side-effect should be 'rewound' in this
 * function to prevent memory leaks and invalid state carrying over into other
 * requests
 */


var resolveSideEffects = function resolveSideEffects() {
  return {
    head: _reactHelmet.default.rewind(),
    redirect: _mwpRouter.Redirect.rewind(),
    forbidden: _mwpRouter.Forbidden.rewind(),
    notFound: _mwpRouter.NotFound.rewind()
  };
};
/**
 * Get media from X-UA-Device header set by Fastly which parses the user agent string
 */


var getMedia = function getMedia(userAgent, userAgentDevice) {
  var isAtSmallUp = true;
  var isMobile = true;
  var isTablet = false;

  if (userAgentDevice) {
    isMobile = userAgentDevice === 'smartphone' || userAgentDevice === 'mobilebot' || userAgentDevice === 'mobile';
    isTablet = userAgentDevice === 'tablet';
  } else {
    var mobileDetect = new _mobileDetect.default(userAgent);
    isMobile = Boolean(mobileDetect.phone());
    isTablet = Boolean(mobileDetect.tablet());
  }

  return {
    isAtSmallUp: isAtSmallUp,
    isAtMediumUp: isTablet || !isMobile,
    isAtLargeUp: !isMobile && !isTablet
  };
}; // get initial server-rendered app metadata that can be consumed by the application
// from mwp-app-render/src/components/AppContext.Consumer


var getAppContext = function getAppContext(request, enableServiceWorker) {
  var url = request.url,
      headers = request.headers,
      info = request.info,
      server = request.server,
      state = request.state; // request protocol and host might be different from original request that hit proxy
  // we want to use the proxy's protocol and host

  var requestProtocol = headers['x-forwarded-proto'] || server.info.protocol;
  var domain = headers['x-forwarded-host'] || headers['x-meetup-host'] || info.host;
  var clientIp = request.query.__set_geoip || headers['fastly-client-ip'] || info.remoteAddress;
  var host = "".concat(requestProtocol, "://").concat((0, _domainCleanup.domainCleanup)(domain));
  var userAgent = headers['user-agent'];
  var userAgentDevice = headers['x-ua-device'] || ''; // set by fastly

  var requestLanguage = request.getLanguage();
  return {
    apiUrl: _mwpApiProxyPlugin.API_ROUTE_PATH,
    baseUrl: host,
    basename: requestLanguage === 'en-US' ? '' : "/".concat(requestLanguage),
    // basename is the 'base path' for the application - usually a localeCode
    enableServiceWorker: enableServiceWorker,
    requestLanguage: requestLanguage,
    supportedLangs: server.settings.app.supportedLangs,
    initialNow: new Date().getTime(),
    isProdApi: server.settings.app.api.isProd,
    isQL: (0, _cookieUtils.parseMemberCookie)(state).ql === 'true',
    memberId: (0, _cookieUtils.parseMemberCookie)(state).id,
    // deprecated, use member.id
    // the member cookie is not structured the same way as the member object returned from /member/self
    // be careful relying on it to have the same properties downstream
    member: (0, _cookieUtils.parseMemberCookie)(state),
    geo: (0, _requestUtils.getRemoteGeoLocation)(request),
    variants: (0, _cookieUtils2.getVariants)(state),
    entryPath: url.pathname,
    // the path that the user entered the app on
    media: getMedia(userAgent, userAgentDevice),
    browserId: (0, _cookieUtils2.parseBrowserIdCookie)(state),
    clientIp: clientIp,
    siftSessionId: (0, _cookieUtils2.parseSiftSessionCookie)(state),
    isBot: (0, _isbot.default)(request.headers['user-agent']),
    preferredTimeZone: (0, _cookieUtils2.parsePreferredTimeZoneCookie)(state)
  };
};
/**
 * Using the current route information and Redux store, render the app to an
 * HTML string and server response code, with optional cookies to write
 */


var getRouterRenderer =
/*#__PURE__*/
function () {
  var _ref2 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(_ref) {
    var request, h, appContext, routes, store, scripts, cssLinks, client, initialState, appMarkup, routerContext, sideEffects, externalRedirect, internalRedirect, redirect, result, statusCode;
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            request = _ref.request, h = _ref.h, appContext = _ref.appContext, routes = _ref.routes, store = _ref.store, scripts = _ref.scripts, cssLinks = _ref.cssLinks, client = _ref.client;
            // pre-render the app-specific markup, this is the string of markup that will
            // be managed by React on the client.
            //
            // **IMPORTANT**: this string is built separately from `<Dom />` because it
            // initializes page-specific state that `<Dom />` needs to render, e.g.
            // `<head>` contents
            initialState = store.getState();
            routerContext = {};
            _context.prev = 3;
            _context.next = 6;
            return (0, _reactApollo.renderToStringWithData)(_react.default.createElement(_ServerApp.default, {
              client: client,
              request: request,
              h: h,
              appContext: appContext,
              routerContext: routerContext,
              store: store,
              routes: routes
            }));

          case 6:
            appMarkup = _context.sent;
            _context.next = 13;
            break;

          case 9:
            _context.prev = 9;
            _context.t0 = _context["catch"](3);
            // cleanup all react-side-effect components to prevent error/memory leaks
            resolveSideEffects(); // now we can re-throw and let the caller handle the error

            throw _context.t0;

          case 13:
            sideEffects = resolveSideEffects();
            externalRedirect = (0, _getRedirect.default)(sideEffects.redirect);
            internalRedirect = (0, _getRedirect.default)(routerContext);
            redirect = internalRedirect || externalRedirect;

            if (!redirect) {
              _context.next = 19;
              break;
            }

            return _context.abrupt("return", redirect);

          case 19:
            // cssLinks can be an Array or a Function that returns an array
            if (typeof cssLinks === 'function') {
              // invoke function and provide initialState
              cssLinks = cssLinks(initialState);
            } // all the data for the full `<html>` element has been initialized by the app
            // so go ahead and assemble the full response body


            _context.next = 22;
            return getHtml(_react.default.createElement(_Dom.default, {
              head: sideEffects.head,
              initialState: initialState,
              appContext: appContext,
              appMarkup: appMarkup,
              scripts: scripts,
              cssLinks: cssLinks
            }));

          case 22:
            result = _context.sent;
            // prioritized status code fallbacks
            statusCode = sideEffects.forbidden || sideEffects.notFound || 200;
            return _context.abrupt("return", {
              statusCode: statusCode,
              result: result
            });

          case 25:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[3, 9]]);
  }));

  return function getRouterRenderer(_x) {
    return _ref2.apply(this, arguments);
  };
}();
/**
 * Curry a function that takes a Hapi request and returns a Promise
 * that will emit the rendered HTML
 *
 * The outer function takes app-specific information about the routes,
 * reducer, and optional additional middleware
 */


var makeRenderer = function makeRenderer(renderConfig) {
  var routes = renderConfig.routes,
      reducer = renderConfig.reducer,
      middleware = renderConfig.middleware,
      scripts = renderConfig.scripts,
      cssLinks = renderConfig.cssLinks,
      enableServiceWorker = renderConfig.enableServiceWorker; // set up a Promise that emits the resolved routes - this single Promise will
  // be reused for all subsequent requests, so we're not resolving the routes repeatedly
  // hooray performance

  var routesPromise = (0, _util.resolveAllRoutes)(routes);
  return function (request, h) {
    if (!scripts.length) {
      throw new Error('No client script assets specified');
    }

    var client = (0, _getClient.default)(true);
    var appContext = getAppContext(request, enableServiceWorker); // create the store with populated `config`

    var initializeStore = function initializeStore(resolvedRoutes) {
      var createStore = (0, _server.getServerCreateStore)((0, _util.getFindMatches)(resolvedRoutes, appContext.basename), middleware || [], request);
      var initialState = {
        config: appContext
      };
      return Promise.resolve(createStore(reducer, initialState));
    }; // otherwise render using the API and React router
    // addFlags is called twice in order to ensure that
    // there is a full member object available in state
    // feature flags can be selected based on member id,
    // email, and other properties.
    // feature flags based on member id are available before the store is populated.


    var addFlags = function addFlags(populatedStore, member) {
      // Populate a LaunchDarklyUser object from member and request details
      var launchDarklyUser = (0, _launchDarkly.getLaunchDarklyUser)(member, request);
      return request.server.plugins['mwp-app-route'].getFlags(launchDarklyUser).then(function (flags) {
        return populatedStore.dispatch({
          type: 'UPDATE_FLAGS',
          payload: flags
        });
      });
    };

    var checkReady = function checkReady(state) {
      return state.preRenderChecklist.every(function (isReady) {
        return isReady;
      });
    };

    var populateStore = function populateStore(store) {
      return new Promise(function (resolve, reject) {
        // dispatch SERVER_RENDER to kick off API middleware
        var _request$url = request.url,
            pathname = _request$url.pathname,
            search = _request$url.search,
            hash = _request$url.hash;
        var location = {
          pathname: pathname,
          search: search,
          hash: hash
        };
        store.dispatch({
          type: _mwpRouter.SERVER_RENDER,
          payload: location
        });

        if (checkReady(store.getState())) {
          // we need to use the _latest_ version of the member object
          // which is why memberObj is defined after the checkReady call.
          var memberObj = (store.getState().api.self || {}).value || {};
          addFlags(store, memberObj).then(function () {
            resolve(store);
          });
          return;
        }

        var unsubscribe = store.subscribe(function () {
          if (checkReady(store.getState())) {
            // we need to use the _latest_ version of the member object
            // which is why memberObj is defined after the checkReady call.
            var _memberObj = (store.getState().api.self || {}).value || {};

            addFlags(store, _memberObj).then(function () {
              resolve(store);
              unsubscribe();
            });
          }
        });
      });
    };

    return routesPromise.then(function (resolvedRoutes) {
      return initializeStore(resolvedRoutes).then(function (store) {
        // the initial addFlags call will only be key'd by member ID
        return addFlags(store, {
          id: (0, _cookieUtils.parseMemberCookie)(request.state).id
        }).then(function () {
          return populateStore(store);
        }).then(function (store) {
          return getRouterRenderer({
            request: request,
            h: h,
            appContext: appContext,
            routes: resolvedRoutes,
            store: store,
            scripts: scripts,
            cssLinks: cssLinks,
            client: client
          });
        });
      });
    });
  };
};

var _default = makeRenderer;
exports.default = _default;
//# sourceMappingURL=server-render.js.map