"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getVariants = exports.parseSiftSessionCookie = exports.parseBrowserIdCookie = exports.parsePreferredTimeZoneCookie = exports.parseMemberCookie = exports.SIFT_SESSION_COOKIE = exports.BROWSER_ID_COOKIE = exports.MEMBER_COOKIE = void 0;

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _qs = _interopRequireDefault(require("qs"));

var _mwpConfig = _interopRequireDefault(require("mwp-config"));

var appConfig = _mwpConfig.default.getServer().properties;

var PREFERRED_TIMEZONE_COOKIE = 'MEETUP_PREFERRED_TIMEZONE';
var MEMBER_COOKIE = appConfig.api.isProd ? 'MEETUP_MEMBER' : 'MEETUP_MEMBER_DEV';
exports.MEMBER_COOKIE = MEMBER_COOKIE;
var BROWSER_ID_COOKIE = appConfig.api.isProd ? 'MEETUP_BROWSER_ID' : 'MEETUP_BROWSER_ID_DEV'; // SIFT_SESSION_ID cookie created in fastly and used by sift science to correlate spammy
// behavior to user activity; cookie has an expiration time of 4 hours and should be
// reset on logout. For more details please refer  https://sift.com/resources/tutorials/anonymous-users

exports.BROWSER_ID_COOKIE = BROWSER_ID_COOKIE;
var SIFT_SESSION_COOKIE = appConfig.api.isProd ? 'SIFT_SESSION_ID' : 'SIFT_SESSION_ID_DEV';
exports.SIFT_SESSION_COOKIE = SIFT_SESSION_COOKIE;

var parseMemberCookie = function parseMemberCookie(state) {
  if (!state[MEMBER_COOKIE]) {
    // no member cookie - this is only possible for 'internal' requests, e.g. health checks.
    // always return id=0 to keep basic member object valid
    return {
      id: 0
    };
  }

  var member = _qs.default.parse(state[MEMBER_COOKIE]);

  member.id = parseInt(member.id, 10) || 0;
  return member;
};

exports.parseMemberCookie = parseMemberCookie;

var parsePreferredTimeZoneCookie = function parsePreferredTimeZoneCookie(state) {
  if (!state[PREFERRED_TIMEZONE_COOKIE]) {
    return '';
  }

  var preferredTimeZone = _qs.default.parse(state[PREFERRED_TIMEZONE_COOKIE]);

  if ((0, _typeof2.default)(preferredTimeZone) === 'object' && Object.keys(preferredTimeZone).length && typeof Object.keys(preferredTimeZone)[0] === 'string' && Object.keys(preferredTimeZone)[0].length) {
    return Object.keys(preferredTimeZone)[0];
  }

  return '';
};

exports.parsePreferredTimeZoneCookie = parsePreferredTimeZoneCookie;

var parseBrowserIdCookie = function parseBrowserIdCookie(state) {
  if (!state[BROWSER_ID_COOKIE]) {
    return {
      id: ''
    };
  }

  var browserId = _qs.default.parse(state[BROWSER_ID_COOKIE]);

  return browserId;
};

exports.parseBrowserIdCookie = parseBrowserIdCookie;

var parseSiftSessionCookie = function parseSiftSessionCookie(state) {
  return state[SIFT_SESSION_COOKIE] || '';
};
/*
 * Some variant settings can be passed in from MEETUP_VARIANT_XXX cookies. This
 * function reads those cookie values from `state` and returns a map of values
 */


exports.parseSiftSessionCookie = parseSiftSessionCookie;

var getVariants = function getVariants(state) {
  return Object.keys(state).reduce(function (variants, cookieName) {
    var isEnvCookie = !(appConfig.api.isProd ^ !cookieName.endsWith('_DEV')); // XNOR - both conditions or neither condition

    if (cookieName.startsWith('MEETUP_VARIANT_') && isEnvCookie) {
      variants[cookieName.replace(/^MEETUP_VARIANT_|_DEV$/g, '')] = state[cookieName];
    }

    return variants;
  }, {});
};

exports.getVariants = getVariants;
//# sourceMappingURL=cookieUtils.js.map