"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _cookieUtils = require("./cookieUtils");

describe('parseMemberCookie', function () {
  it('returns the parsed cookie', function () {
    var requestState = (0, _defineProperty2.default)({}, _cookieUtils.MEMBER_COOKIE, 'foo=bar&baz=bing');
    expect((0, _cookieUtils.parseMemberCookie)(requestState)).toEqual({
      foo: 'bar',
      baz: 'bing',
      id: 0
    });
  });
  it('returns an integer id', function () {
    var values = ['foo=bar&baz=bing', // no id
    'id=fabulous', 'id=0', 'id=1234', ''];
    values.map(function (v) {
      return (0, _defineProperty2.default)({}, _cookieUtils.MEMBER_COOKIE, v);
    }).forEach(function (state) {
      return expect((0, _cookieUtils.parseMemberCookie)(state).id).toEqual(expect.any(Number));
    });
  });
  it('returns an integer id', function () {
    var ids = [1, 0, 'fabulous'];
    var resultIds = ids.map(function (id) {
      return (0, _defineProperty2.default)({}, _cookieUtils.MEMBER_COOKIE, "id=".concat(id));
    }).map(_cookieUtils.parseMemberCookie).map(function (member) {
      return member.id;
    });
    expect(resultIds).toEqual(ids.map(function (id) {
      return parseInt(id.toString(), 10) || 0;
    }));
  });
  it('returns {id:0} for no-cookie case', function () {
    expect((0, _cookieUtils.parseMemberCookie)({})).toEqual({
      id: 0
    });
  });
});
describe('parseBrowserIdCookie', function () {
  it('returns a browser id', function () {
    var requestState = (0, _defineProperty2.default)({}, _cookieUtils.BROWSER_ID_COOKIE, 'id=abc-def-g1234');
    expect((0, _cookieUtils.parseBrowserIdCookie)(requestState)).toEqual({
      id: 'abc-def-g1234'
    });
  });
  it('returns an empty string for the id value when there is no id', function () {
    var requestState = (0, _defineProperty2.default)({}, _cookieUtils.BROWSER_ID_COOKIE, '');
    expect((0, _cookieUtils.parseBrowserIdCookie)(requestState)).toEqual({
      id: ''
    });
  });
  it('returns an empty string for the id value when there is no browser id cookie', function () {
    expect((0, _cookieUtils.parseBrowserIdCookie)({})).toEqual({
      id: ''
    });
  });
});
describe('parseSiftSessionIdCookie', function () {
  it('returns a sift session id', function () {
    var requestState = (0, _defineProperty2.default)({}, _cookieUtils.SIFT_SESSION_COOKIE, 'bfb3860d-36b4-417c-9ead-99bcc036cf88');
    expect((0, _cookieUtils.parseSiftSessionCookie)(requestState)).toEqual('bfb3860d-36b4-417c-9ead-99bcc036cf88');
  });
  it('returns an empty object when there is no SIFT_SESSION_COOKIE', function () {
    var requestState = (0, _defineProperty2.default)({}, _cookieUtils.SIFT_SESSION_COOKIE, '');
    expect((0, _cookieUtils.parseSiftSessionCookie)(requestState)).toEqual('');
  });
});
describe('getVariants', function () {
  it('creates an object', function () {
    expect((0, _cookieUtils.getVariants)({})).toEqual(expect.any(Object));
    expect((0, _cookieUtils.getVariants)({
      foo: 'bar'
    })).toEqual(expect.any(Object));
    expect((0, _cookieUtils.getVariants)({
      MEETUP_VARIANT_FOO_DEV: 'bar'
    })).toEqual(expect.any(Object));
  });
  it('extracts suffix-free key from MEETUP_VARIANT_XXX_DEV', function () {
    var val = 'bar';
    expect((0, _cookieUtils.getVariants)({
      MEETUP_VARIANT_FOO_DEV: val
    }).FOO).toEqual(val);
  });
});
//# sourceMappingURL=cookieUtils.test.js.map