"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLaunchDarklyUser = void 0;

var _requestUtils = require("./requestUtils");

/**
 * Populates a LaunchDarklyUser object with member and request properties.
 *
 * @param member  a member state object
 * @param request a request object
 */
var getLaunchDarklyUser = function getLaunchDarklyUser(member, request) {
  var id = member.id,
      name = member.name,
      email = member.email,
      country = member.country;
  var ip = (0, _requestUtils.getRemoteIp)(request);
  var key = id && id.toString() || '0';
  var anonymous = key === '0';
  var custom = getCustomAttributes(request);
  var user = {
    key: key,
    anonymous: anonymous,
    custom: custom
  };

  if (ip) {
    user.ip = ip;
  }

  if (name) {
    user.name = name;
  }

  if (email) {
    user.email = email;
  }

  if (country) {
    user.country = country;
  }

  return user;
}; // Builds LaunchDarklyUser custom attributes. Custom attributes can contain arbitrary values
// and can be used for targeting. Read more at https://docs.launchdarkly.com/docs/node-sdk-reference#section-users.


exports.getLaunchDarklyUser = getLaunchDarklyUser;

var getCustomAttributes = function getCustomAttributes(request) {
  var geoLocation = (0, _requestUtils.getRemoteGeoLocation)(request);
  var custom = {};

  if (geoLocation.country) {
    custom.RequestCountry = geoLocation.country.toUpperCase();
  }

  if (geoLocation.region) {
    custom.RequestRegion = geoLocation.region.toUpperCase();
  }

  return custom;
};
//# sourceMappingURL=launchDarkly.js.map