"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _launchDarkly = require("./launchDarkly");

describe('getLaunchDarklyUser', function () {
  var REQUEST_MOCK = {
    info: {},
    headers: {},
    query: {}
  };
  it('creates an anonymous user for an empty member object', function () {
    var user = (0, _launchDarkly.getLaunchDarklyUser)({}, REQUEST_MOCK);
    expect(user).toEqual({
      key: '0',
      anonymous: true,
      custom: {}
    });
  });
  it('creates an anonymous user for an anonymous member', function () {
    var member = {
      id: 0
    };
    var user = (0, _launchDarkly.getLaunchDarklyUser)(member, REQUEST_MOCK);
    expect(user).toEqual({
      key: '0',
      anonymous: true,
      custom: {}
    });
  });
  it('populates a user with member details', function () {
    var member = {
      id: 12345,
      name: 'Test User',
      email: 'test@test.test',
      country: 'US'
    };
    var user = (0, _launchDarkly.getLaunchDarklyUser)(member, REQUEST_MOCK);
    expect(user).toEqual({
      key: '12345',
      name: 'Test User',
      email: 'test@test.test',
      country: 'US',
      anonymous: false,
      custom: {}
    });
  });
  it('sets an IP address if it was resolved from a request', function () {
    var request = (0, _objectSpread2.default)({}, REQUEST_MOCK, {
      query: {
        __set_geoip: '89.22.50.79'
      }
    });
    var user = (0, _launchDarkly.getLaunchDarklyUser)({}, request);
    expect(user.ip).toBe('89.22.50.79');
  });
  describe('Custom attributes', function () {
    it('does not populate custom attributes if neither country nor region were resolved from a request', function () {
      var user = (0, _launchDarkly.getLaunchDarklyUser)({}, REQUEST_MOCK);
      expect(user.custom).toEqual({});
    });
    it('sets RequestCountry custom attribute to an uppercased request country', function () {
      var request = (0, _objectSpread2.default)({}, REQUEST_MOCK, {
        headers: {
          'x-region': 'us/'
        }
      });
      var user = (0, _launchDarkly.getLaunchDarklyUser)({}, request);
      expect(user.custom).toEqual({
        RequestCountry: 'US'
      });
    });
    it('sets RequestRegion custom attribute to an uppercased request region', function () {
      var request = (0, _objectSpread2.default)({}, REQUEST_MOCK, {
        headers: {
          'x-region': 'us/ut'
        }
      });
      var user = (0, _launchDarkly.getLaunchDarklyUser)({}, request);
      expect(user.custom).toEqual({
        RequestCountry: 'US',
        RequestRegion: 'UT'
      });
    });
  });
});
//# sourceMappingURL=launchDarkly.test.js.map