"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = linkify;
exports.getSubDomain = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

// Regex to match urls, copied from url-regex v3. Modified to not match closing parantheses ')' at the end of the url string
var urlRegex = new RegExp(/(?:(?:(?:[a-z]+:)?\/\/)|www\.)(?:\S+(?::\S*)?@)?(?:localhost|(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])(?:\.(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])){3}|(?:(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)(?:\.(?:[a-z\u00a1-\uffff0-9]-*)*[a-z\u00a1-\uffff0-9]+)*(?:\.(?:[a-z\u00a1-\uffff]{2,})))(?::\d{2,5})?(?:[/?#]([^\s"()]|[(][^\s"]*?[)])*)?/gi);
var MEETUP_DOMAINS = ['meetup.com', 'secure.meetupstatic.com', 'meetu.ps'];

var getRelAttr = function getRelAttr(followedExternalDomains, link, target) {
  if (!followedExternalDomains) {
    return target === '_blank' ? 'rel="nofollow noopener noreferrer"' : '';
  }

  try {
    var urlObj = new URL(link);
    var domain = urlObj.hostname.replace('www.', '');

    if (MEETUP_DOMAINS.includes(domain)) {
      return '';
    } else if (followedExternalDomains.includes(domain)) {
      return 'rel="ugc"';
    }

    return 'rel="nofollow ugc"';
  } catch (error) {
    return 'rel="nofollow ugc"';
  }
};

var getSubDomain = function getSubDomain(url) {
  if (!url || !url.includes("//")) {
    return 'www';
  }

  var _url$split = url.split("//"),
      _url$split2 = (0, _slicedToArray2.default)(_url$split, 2),
      domain = _url$split2[1];

  if (domain) {
    var levels = domain.split('.');

    if (levels.length > 2) {
      var _domain$split = domain.split('.'),
          _domain$split2 = (0, _slicedToArray2.default)(_domain$split, 1),
          subdomain = _domain$split2[0];

      return subdomain || 'www';
    }
  }

  return 'www';
};
/**
 * Generates HTML link tag element with target
 *
 * @method createLink
 * @param {Object} options optional modifiers
 * @param {String} href string of link passed through options
 * @return {String} The HTML link tag
 */


exports.getSubDomain = getSubDomain;

var createLink = function createLink(options, followedExternalDomains) {
  return function (href) {
    var target = options.target || '';
    var targetAttr = "target=\"".concat(target, "\"");
    var hasProtocolRE = /^(?:https?:|ws:|ftp:)?\/\//;
    var hasMeetupHttpLinkRE = /https?:\/\/([a-z0-9-]+?\.)?meetup/g;
    var meetupHttps = "https://".concat(getSubDomain(href), ".meetup");
    var link = hasProtocolRE.test(href) ? href : "http://".concat(href);
    var meetupLink = link.replace(hasMeetupHttpLinkRE, meetupHttps);
    var isMeetupLinkUpdated = meetupLink !== link;
    var relAttr = getRelAttr(followedExternalDomains, link, target);
    return isMeetupLinkUpdated ? "<a class=\"link\" href=\"".concat(meetupLink, "\" title=\"").concat(meetupLink, "\" ").concat(targetAttr, " ").concat(relAttr, ">").concat(meetupLink, "</a>") : "<a class=\"link\" href=\"".concat(link, "\" title=\"").concat(href, "\" ").concat(targetAttr, " ").concat(relAttr, ">").concat(href, "</a>");
  };
};
/**
 * Replaces URLs in a block of text with HTML anchor tags.
 *
 * @method linkify
 * @param {String} text The text on which to operate
 * @param {Object} options optional modifiers
 * @return {String} The modified text.
 */


function linkify(text) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var followedExternalDomains = arguments.length > 2 ? arguments[2] : undefined;

  if (!text) {
    return '';
  }

  return text.replace(urlRegex, createLink(options, followedExternalDomains));
}
//# sourceMappingURL=linkify.js.map