"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _linkify = _interopRequireWildcard(require("./linkify"));

describe('getSubDomain', function () {
  it('should return corrent url subdomain', function () {
    expect((0, _linkify.getSubDomain)()).toBe('www');
    expect((0, _linkify.getSubDomain)("meetup.com")).toBe('www');
    expect((0, _linkify.getSubDomain)("http://meetup.com")).toBe('www');
    expect((0, _linkify.getSubDomain)("https://meetup.com")).toBe('www');
    expect((0, _linkify.getSubDomain)("http://www.meetup.com")).toBe('www');
    expect((0, _linkify.getSubDomain)("https://www.meetup.com")).toBe('www');
    expect((0, _linkify.getSubDomain)("http://secure.meetup.com")).toBe('secure');
    expect((0, _linkify.getSubDomain)("https://secure.meetup.com")).toBe('secure');
    expect((0, _linkify.getSubDomain)("http://www.amazon.co.uk")).toBe('www');
    expect((0, _linkify.getSubDomain)("https://www.amazon.co.uk")).toBe('www');
  });
});
describe('linkify', function () {
  var httpBase = 'http://www.meetup.com';
  var secureBase = 'https://secure.meetup.com';
  var expectedLink = '<a class="link" href="https://www.meetup.com" title="https://www.meetup.com" target="" >https://www.meetup.com</a>';
  it('should turn a meetup link text with http into a HTML anchor with https', function () {
    expect((0, _linkify.default)(httpBase)).toBe(expectedLink);
  });
  it('should turn a meetup link text with http and without www into a HTML anchor with https and www', function () {
    expect((0, _linkify.default)('http://meetup.com')).toBe(expectedLink);
  });
  it('should turn a link text with https into a HTML anchor with https', function () {
    var expectedSecureLink = '<a class="link" href="https://secure.meetup.com" title="https://secure.meetup.com" target="" >https://secure.meetup.com</a>';
    expect((0, _linkify.default)(secureBase)).toBe(expectedSecureLink);
  });
  it('should turn a link text with a target into an HTML anchor with a target', function () {
    var targetLink = '<a class="link" href="https://www.meetup.com" title="https://www.meetup.com" target="foo" >https://www.meetup.com</a>';
    expect((0, _linkify.default)(httpBase, {
      target: 'foo'
    })).toBe(targetLink);
  });
  it('should turn a link text with a `_blank` target into an HTML anchor with `rel="nofollow noopener noreferrer"`', function () {
    expect((0, _linkify.default)(httpBase, {
      target: '_blank'
    })).toContain('rel="nofollow noopener noreferrer"');
  });
  it('should turn a link text without a `_blank` target into an HTML anchor without `rel="nofollow noopener noreferrer"`', function () {
    expect((0, _linkify.default)(httpBase)).not.toContain('rel="nofollow noopener noreferrer"');
  });
  it('should not turn a text without a link into text with an HTML anchor', function () {
    var noLinkText = 'This is not a link.';
    expect((0, _linkify.default)(noLinkText)).toBe(noLinkText);
    expect((0, _linkify.default)(noLinkText)).not.toContain('</a>');
  });
  it('should turn a text with a link into text with an HTML anchor', function () {
    var paragraphTextBase = "Did you know ".concat(httpBase, " is a cool site?");
    var expectedParagraphLink = "Did you know ".concat(expectedLink, " is a cool site?");
    expect((0, _linkify.default)(paragraphTextBase)).toBe(expectedParagraphLink);
  });
  it('should prefix a plain link with a protocol', function () {
    var plainBase = 'www.meetup.com';
    var expectedLink = '<a class="link" href="https://www.meetup.com" title="https://www.meetup.com" target="" >https://www.meetup.com</a>';
    expect((0, _linkify.default)(plainBase)).toBe(expectedLink);
  });
});
describe('url matching', function () {
  // most of these test urls were copied from url-regex
  var urlsShouldMatch = ['http://foo.com/blah_blah', 'http://foo.com/blah_blah/', 'http://foo.com/blah_blah_(wikipedia)', 'http://foo.com/blah_blah_(wikipedia)_(again)', 'http://www.example.com/wpstyle/?p=364', 'https://www.example.com/foo/?bar=baz&inga=42&quux', 'http://a.b.c.d.e.f.g.h.i.j.k.l.m.n.o.p.q.r.s.t.u.v.w.x.y.z.com', 'http://mw1.google.com/mw-earth-vectordb/kml-samples/gp/seattle/gigapxl/$[level]/r$[y]_c$[x].jpg', 'http://user:pass@example.com:123/one/two.three?q1=a1&q2=a2#body', 'http://www.microsoft.xn--comindex-g03d.html.irongeek.com', 'http://✪df.ws/123', 'http://localhost/', 'http://userid:password@example.com:8080', 'http://userid:password@example.com:8080/', 'http://userid@example.com', 'http://userid@example.com/', 'http://userid@example.com:8080', 'http://userid@example.com:8080/', 'http://userid:password@example.com', 'http://userid:password@example.com/', 'http://142.42.1.1/', 'http://142.42.1.1:8080/', 'http://➡.ws/䨹', 'http://⌘.ws', 'http://⌘.ws/', 'http://foo.com/blah_(wikipedia)#cite-1', 'http://foo.com/blah_(wikipedia)_blah#cite-1', 'http://foo.com/unicode_(✪)_in_parens', 'http://foo.com/(something)?after=parens', 'http://☺.damowmow.com/', 'http://code.google.com/events/#&product=browser', 'http://j.mp', 'ftp://foo.bar/baz', 'http://foo.bar/?q=Test%20URL-encoded%20stuff', 'http://مثال.إختبار', 'http://例子.测试', 'http://उदाहरण.परीक्षा', "http://-.~_!$&'()*+';=:%40:80%2f::::::@example.com", 'http://1337.net', 'http://a.b-c.de', 'http://223.255.255.254', 'http://example.com?foo=bar', 'http://example.com#foo', 'ws://localhost:8080', 'ws://foo.ws', 'ws://a.b-c.de', 'ws://223.255.255.254', 'ws://userid:password@example.com', 'ws://➡.ws/䨹', '//localhost:8080', '//foo.ws', '//a.b-c.de', '//223.255.255.254', '//userid:password@example.com', '//➡.ws/䨹', 'http://www.restaurant.com/menu(1).pdf', 'http://www.restaurant.com/menu(foo)(bar).pdf', 'http://www.example.com/menu(wikipedia)', 'http://m.com/menu(1)new(2).pdf', 'http://foo.com/(something)?after=parenthe'];
  var urlsShouldNotMatch = ['http://', 'http://.', 'http://..', 'http://../', 'http://?', 'http://??', 'http://??/', 'http://#', 'http://##', 'http://##/', '//', '//a', '///a', '///', 'http:///a', 'foo.com', 'rdar://1234', 'h://test', 'http:// shouldfail.com', ':// should fail', 'http://-error-.invalid/', 'http://-a.b.co', 'http://a.b-.co', 'http://123.123.123', 'http://3628126748', 'http://go/ogle.com', 'http://google\\.com', 'http://www(google.com', 'http://www=google.com', 'rdar://1234', '/foo.bar/'];
  urlsShouldMatch.forEach(function (url) {
    it("should match ".concat(url), function () {
      var plainText = "Check out my meetup (".concat(url, "). It's awesome.");
      var expected = "Check out my meetup (<a class=\"link\" href=\"".concat(url, "\" title=\"").concat(url, "\" target=\"\" >").concat(url, "</a>). It's awesome.");
      expect((0, _linkify.default)(plainText)).toBe(expected);
    });
  });
  urlsShouldNotMatch.forEach(function (url) {
    it("should not match ".concat(url), function () {
      var plainText = "Check out my meetup (".concat(url, "). It's awesome.");
      expect((0, _linkify.default)(plainText)).toBe(plainText);
    });
  });
});
describe('rel attribute', function () {
  it('should not render a rel attribute', function () {
    var expectedLink = '<a class="link" href="https://www.meetup.com" title="https://www.meetup.com" target="" >https://www.meetup.com</a>';
    expect((0, _linkify.default)('https://www.meetup.com', {}, ['youtube.com'])).toBe(expectedLink);
  });
  it('should not render a rel attribute for meetupstatic', function () {
    var expectedLink = '<a class="link" href="https://secure.meetupstatic.com" title="https://secure.meetupstatic.com" target="" >https://secure.meetupstatic.com</a>';
    expect((0, _linkify.default)('https://secure.meetupstatic.com', {}, ['youtube.com'])).toBe(expectedLink);
  });
  it('should not render a rel attribute for meetu.ps', function () {
    var expectedLink = '<a class="link" href="https://meetu.ps" title="https://meetu.ps" target="" >https://meetu.ps</a>';
    expect((0, _linkify.default)('https://meetu.ps', {}, ['youtube.com'])).toBe(expectedLink);
  });
  it('should render a "ugc" rel attribute', function () {
    var expectedLink = '<a class="link" href="https://www.youtube.com" title="https://www.youtube.com" target="" rel="ugc">https://www.youtube.com</a>';
    expect((0, _linkify.default)('https://www.youtube.com', {}, ['youtube.com'])).toBe(expectedLink);
  });
  it('should render a "nofollow ugc" rel attribute', function () {
    var expectedLink = '<a class="link" href="https://www.non-existing-webstie-12345.com" title="https://www.non-existing-webstie-12345.com" target="" rel="nofollow ugc">https://www.non-existing-webstie-12345.com</a>';
    expect((0, _linkify.default)('https://www.non-existing-webstie-12345.com', {}, ['youtube.com'])).toBe(expectedLink);
  });
});
//# sourceMappingURL=linkify.test.js.map