"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRemoteGeoLocation = exports.getRemoteIp = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var HEADER_FASTLY_CLIENT_IP = 'fastly-client-ip';
/**
 * Attempts to parse a client IP address from a request.
 *
 * @param request a request
 * @returns { string | undefined } maybe IP address
 */

var getRemoteIp = function getRemoteIp(request) {
  var headers = request.headers,
      info = request.info,
      query = request.query;

  var fromQuery = query && query.__set_geoip && query.__set_geoip.toString();

  var fromHeaders = headers && headers[HEADER_FASTLY_CLIENT_IP];
  var fromInfo = info && typeof info.remoteAddress === 'string' ? info.remoteAddress : undefined;
  return fromQuery || fromHeaders || fromInfo;
};
/**
 * Returns a client geo location map derived from request properties
 *
 * Usually, the parameters are supplied by Fastly custom headers
 *
 * - `x-region`: a string in the format '[countrycode]/[regioncode]'
 * - `x-fastly-geo-city': city name as determined by Fastly
 * - `x-fastly-geo-latlon: string of '[latitude],[longitude]' floats
 *
 * Alternatively, override these value (or supply in dev) using querystring params
 *
 * - `__geo-region`
 * - `__geo-city`
 * - `__geo-latlon`
 */


exports.getRemoteIp = getRemoteIp;

var getRemoteGeoLocation = function getRemoteGeoLocation(request) {
  var headers = request.headers,
      query = request.query;
  var geoLocation = {}; // COUNTRY + REGION

  var location = query['__geo-region'] || headers['x-region'] || '';

  var _location$split = location.split('/'),
      _location$split2 = (0, _slicedToArray2.default)(_location$split, 2),
      country = _location$split2[0],
      region = _location$split2[1];

  if (country) {
    geoLocation.country = country;
  }

  if (region) {
    geoLocation.region = region;
  } // CITY


  var city = query['__geo-city'] || headers['x-fastly-geo-city'];

  if (city) {
    geoLocation.city = city;
  } // LATITUDE/LONGITUDE


  var _split$map = (query['__geo-latlon'] || headers['x-fastly-geo-latlon'] || '').split(',').map(parseFloat),
      _split$map2 = (0, _slicedToArray2.default)(_split$map, 2),
      _split$map2$ = _split$map2[0],
      lat = _split$map2$ === void 0 ? NaN : _split$map2$,
      _split$map2$2 = _split$map2[1],
      lon = _split$map2$2 === void 0 ? NaN : _split$map2$2;

  if (!Number.isNaN(lat) && !Number.isNaN(lon)) {
    geoLocation.latlon = [lat, lon];
  }

  return geoLocation;
};

exports.getRemoteGeoLocation = getRemoteGeoLocation;
//# sourceMappingURL=requestUtils.js.map