"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _requestUtils = require("./requestUtils");

var REQUEST_MOCK = {
  info: {},
  headers: {},
  query: {}
};
describe('getRemoteIp', function () {
  it('returns an IP address from a query string parameter', function () {
    var request = (0, _objectSpread2.default)({}, REQUEST_MOCK, {
      info: {
        remoteAddress: '127.0.0.1'
      },
      headers: {
        'fastly-client-ip': '192.168.0.1'
      },
      query: {
        __set_geoip: '89.22.50.79'
      }
    });
    expect((0, _requestUtils.getRemoteIp)(request)).toEqual('89.22.50.79');
  });
  it('returns an IP address from Fastly header', function () {
    var request = (0, _objectSpread2.default)({}, REQUEST_MOCK, {
      info: {
        remoteAddress: '127.0.0.1'
      },
      headers: {
        'fastly-client-ip': '192.168.0.1'
      },
      query: {}
    });
    expect((0, _requestUtils.getRemoteIp)(request)).toEqual('192.168.0.1');
  });
  it('returns an IP address from a request remote address', function () {
    var request = (0, _objectSpread2.default)({}, REQUEST_MOCK, {
      info: {
        remoteAddress: '127.0.0.1'
      },
      headers: {},
      query: {}
    });
    expect((0, _requestUtils.getRemoteIp)(request)).toEqual('127.0.0.1');
  });
  it('returns nothing if none of the methods above yielded a result', function () {
    var request = (0, _objectSpread2.default)({}, REQUEST_MOCK, {
      info: {},
      headers: {},
      query: {}
    });
    expect((0, _requestUtils.getRemoteIp)(request)).toBeUndefined();
  });
});
describe('getRemoteGeoLocation', function () {
  it.each([['empty object for empty geo headers', {}, {}], ['region and country for full x-region', {
    'x-region': 'us/ny'
  }, {
    country: 'us',
    region: 'ny'
  }], ['country only for country-only x-region', {
    'x-region': 'us/'
  }, {
    country: 'us'
  }], ['region ony for region-only x-region', {
    'x-region': '/ny'
  }, {
    region: 'ny'
  }], ['city for x-fastly-geo-city', {
    'x-fastly-geo-city': 'nyc'
  }, {
    city: 'nyc'
  }], ['latlon for x-fastly-geo-latlon', {
    'x-fastly-geo-latlon': '1.2345,2.3456'
  }, {
    latlon: [1.2345, 2.3456]
  }]])('%s', function (_, headers, expected) {
    expect((0, _requestUtils.getRemoteGeoLocation)((0, _objectSpread2.default)({}, REQUEST_MOCK, {
      headers: headers
    }))).toEqual(expected);
  });
  it('overrides all values using querystring', function () {
    var headers = {
      'x-region': 'header-country/header-region',
      'x-fastly-geo-city': 'header-city',
      'x-fastly-geo-latlon': '9.8765,8.76584'
    };
    var query = {
      '__geo-region': 'query-country/query-region',
      '__geo-city': 'query-city',
      '__geo-latlon': '1.2345,2.3456'
    };
    var expected = {
      country: 'query-country',
      region: 'query-region',
      city: 'query-city',
      latlon: [1.2345, 2.3456]
    };
    expect((0, _requestUtils.getRemoteGeoLocation)((0, _objectSpread2.default)({}, REQUEST_MOCK, {
      headers: headers,
      query: query
    }))).toEqual(expected);
  });
});
//# sourceMappingURL=requestUtils.test.js.map